# ServiceInstaller

A simple Python module to automate the installation of system services.
Currently compatible with Systemd services on Linux.
Used by the Brokkr and Sindri packages as part of the Mjolnir project.
Distributed under the terms of the MIT (Expat) license.
See the ``install_service`` docstring for more details on usage.



## Installation and Setup

Built and tested under Python 3.7 (but should be compatible with Python >=3.6; lack thereof should be considered a bug).
Currently only compatible with Linux, but no dependencies required.
